#
# spec file for package qtile
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with test
Name:           qtile
Version:        0.15.1
Release:        2.4
Summary:        A pure-Python tiling window manager
# All MIT except for: libqtile/widget/pacman.py:GPL (v3 or later)
License:        MIT AND GPL-3.0-or-later
Group:          System/X11/Displaymanagers
URL:            http://qtile.org
Source:         https://github.com/qtile/qtile/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}-rpmlintrc
BuildRequires:  fdupes
BuildRequires:  libpulse-devel
BuildRequires:  python-rpm-macros
BuildRequires:  python3-cairocffi >= 1.0.2
BuildRequires:  python3-cffi >= 1.11.5
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-six >= 1.11.0
BuildRequires:  python3-xcffib >= 0.8.1
BuildRequires:  update-desktop-files
Requires:       python3-cairocffi >= 0.9.0
Requires:       python3-cairocffi-pixbuf >= 0.9.0
Requires:       python3-cffi >= 1.11.5
Requires:       python3-six >= 1.11.0
Requires:       python3-xcffib >= 0.8.1
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     libxcb-cursor0
Recommends:     pulseaudio
Recommends:     python3-iwlib
Recommends:     python3-keyring
Recommends:     python3-psutil
Recommends:     python3-python-dateutil
Recommends:     python3-python-mpd2
Recommends:     python3-pyxdg
Suggests:       python3-jupyter_console
Suggests:       python3-jupyter_ipykernel
%if %{with test}
BuildRequires:  ImageMagick
BuildRequires:  python3-cairocffi-pixbuf >= 0.9.0
BuildRequires:  python3-curses
BuildRequires:  python3-dbus-python
BuildRequires:  python3-flake8
BuildRequires:  python3-iwlib
BuildRequires:  python3-jupyter_console
BuildRequires:  python3-jupyter_ipykernel
BuildRequires:  python3-keyring
BuildRequires:  python3-pep8-naming
BuildRequires:  python3-psutil
BuildRequires:  python3-pytest
BuildRequires:  python3-pytest-cov
BuildRequires:  python3-python-dateutil
BuildRequires:  python3-python-mpd2
BuildRequires:  python3-pyxdg
BuildRequires:  xcalc
BuildRequires:  xclock
BuildRequires:  xeyes
BuildRequires:  xorg-x11-server-Xvfb
BuildRequires:  xorg-x11-server-extra
BuildRequires:  xrandr
BuildRequires:  xterm
%endif

%description
A pure-Python tiling window manager.
* Extensible in that personal layouts, widgets and commands can be created.
* Configured in Python.
* Command shell that allows all aspects of Qtile to be managed and
  inspected.
* Remote scriptability to set up workspaces,
  manipulate windows, update status bar widgets and more.
* Qtile is unit-tested using this remote scriptability feature.

%prep
%setup -q -n qtile-%{version}
# Fix rpmlint warnings
sed -i 's/#!\/usr\/bin\/env bash/#!\/bin\/bash/' %{_builddir}/qtile-%{version}/bin/dqtile-cmd
sed -i '/#!\/usr\/bin\/env python/d' %{_builddir}/qtile-%{version}/libqtile/scripts/qtile_cmd.py

%build
%python3_build

%install
%python3_install
mkdir -p %{buildroot}%{_datadir}/xsessions/
install -m 644 %{_builddir}/qtile-%{version}/resources/qtile.desktop %{buildroot}%{_datadir}/xsessions/

%suse_update_desktop_file %{buildroot}%{_datadir}/xsessions/qtile.desktop

# default selector for xsession
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/default-xsession.desktop
ln -s %{_sysconfdir}/alternatives/default-xsession.desktop %{buildroot}%{_datadir}/xsessions/default.desktop

%fdupes %{buildroot}%{python3_sitearch}

%if %{with test}
%check
sed -i 's/#!\/usr\/bin\/env python/#!\/usr\/bin\/python3/' bin/qtile-cmd
sed -i -e 's/python/python3/g' scripts/ffibuild
./scripts/ffibuild
%pytest -k  "not test_images"
%endif

%post
%{_sbindir}/update-alternatives --install %{_datadir}/xsessions/default.desktop \
  default-xsession.desktop %{_datadir}/xsessions/qtile.desktop 20

%postun
[ -f %{_datadir}/xsessions/qtile.desktop ] || %{_sbindir}/update-alternatives \
  --remove default-xsession.desktop %{_datadir}/xsessions/qtile.desktop

%files
%ghost %{_sysconfdir}/alternatives/default-xsession.desktop
%ghost %{_sysconfdir}/alternatives/default.desktop
%license LICENSE
%doc CHANGELOG README.rst
%{_bindir}/iqshell
%{_bindir}/qtile
%{_bindir}/qtile-run
%{_bindir}/qtile-top
%{_bindir}/qshell
%{_bindir}/qtile-cmd
%{_bindir}/dqtile-cmd
%{python3_sitearch}/*
%{_mandir}/man1/qtile.1%{?ext_man}
%{_mandir}/man1/qshell.1%{?ext_man}
%{_datadir}/xsessions/default.desktop
%{_datadir}/xsessions/qtile.desktop

%changelog
* Sun May  3 2020 Petr Cervinka <petr@cervinka.net>
- Add pulseaudio support to build and use PulseVolume widget
  * Make package arch dependent, noarch removed
  * Add libpulse-devel to build requirements
  * Add pulseaudio to recommends
- Add support for tests
  * Change source url to GitHub (contain tests)
  * Schedule tests with test condition only
  * Extend build requirements section with test dependencies
  * Exclude test_images tests
- Add update-desktop-files to build requirements and apply macro
  %%suse_update_desktop_file on qtile.desktop
* Tue Apr 14 2020 Petr Cervinka <petr@cervinka.net>
- Update to version 0.15.1:
  * Bugfixes
  - Revert core: properly shutdown event loop (#1615)(#1609)
- Update to version 0.15.0:
  * Config breakage
  - removed the mpd widget, which depended on python-mpd
  * Bugfixes
  - Fix #1298: fall back to get int items for digit string in qtile_cmd.
  - Fix qtile-cmd failure, #1410.
  - Fix #755: use a valid timestamp for WM_TAKE_FOCUS events.
  - Issue #1510: Added missing kwargs argument in EzKey class.
  - Toggle group if setting a group twice. (#1491)
  - Added non-graph CPU widget (feature req #1439)
  - Changes to make the dev.sh script more generic. (#1471)
  - Show current layout and prepare all layouts in the default config. (#1469)
  - Fix #1394: handle empty HOME completion in test_bar.py::test_completion.
  - Center-align groupboxes by default. (#1452)
  - Reorganize and complete hacking.rst (#1442)
  - Update gmail_checker.py (#1448)
  - docs: Fix parameter type of Screen's top/left/right/bottom (#1438)
  - docs: Fix missing psutil mock (#1432)
  - Remove pythonwifi related code in Wlan widget (#1429)
  - Fix command to build cffi module (#1427)
  - Use lazy.lazy in default config instead of command.lazy (deprecated) (#1428)
  - Use new style format in pomodoro widget (#1426)
  - docs: Add missing requirement for Wlan widget (#1400)
  - Use `$PYTHON` instead of `PYTHON`. (#1397)
  - Make it explicit to install cairocffi after xcffib. (#1406)
  - Fix #1407 (missing "-o screen" in "qtile-cmd" output)
  - Small bug fix (#1366)
  - Make the Spacer widget accept a background color (#1365)
  - Fix (#1361) - Battery widget debug info
  - Execute the volume widget commands in a shell (#1359)
  * Features
  - Add pyxdg widget requirement in LaunchBar docstring
  - Add PyCharm debugging instructions in hacking.rst
  - Add missing instruction to build docs in hacking.rst
  - Add more docs and qtile-session file
  - Add notes about graphviz and dev.sh in hacking.rst
  - Add groupbox feature: Font colour when box highlighting
  - add an issue template
  - add callback functions to textbox widget
  - Add test_qtile_cmd.py file.
  - Add a test case for int indexed items in InteractiveCommandClient.
  - add pulseaudio C api based volume control widget
  - add setting wallpapers per Screen, with x11 backend
  - add display option to Net widget and introduce f-strings
  - Add Python script to automate screenshots
  - Add the license header to the xcore file
  - Add ability to use bits as unit in net widget
  - Add a quick_exit widget to __init__.py to pass the static checker(mypy).
  - Add a quick exit widget and add this widget to default configuration that is loaded when configuratin error occured.
  - Add non-graph CPU widget (feature req #1439)
  - Add support for checking updates via yay on Arch
  - Add an error handling when backlight widget failed to read a status file.
  - Add steps about how to run qtile within a virtualenv.
  - Add option "options" to keyboardLayout widget
  - Add gkrellm to run all tests
  - Add note about psutil
  - Add line length to pylintrc
  - Add type annotations to the command object
  - Add a command object that operates against a running command object
  - Add a command graph object for IPC
  - Add functions to the command interface to enable lazy evaluation
  - Add an interface for eagerly evaluating command graph elements
  - Add client to dispatch into command graph
  - Add tests to the command graph
* Mon Aug 12 2019 Petr Cervinka <petr@cervinka.net>
- Increase required cairocffi version
* Mon Jun 24 2019 petr@cervinka.net
- Update to version 0.14.2:
  * Bugfixes
  - previous release still exhibited same issues with package data,
    really fix it this time
- Update to version 0.14.1:
  * Bugfixes
  - properly include png files in the package data to install included icons
- Update to version 0.14.0:
  * Config breakage
  - Many internal things were renamed from camel case to snake case. If
    your config uses main(), or any lazy.function() invocations that
    interact directly with the qtile object, you may need to forward port
    them. Also note that we do *not* consider the qtile object to be a
    stable api, so you will need to continue forward porting these things
    for future refactorings (for wayland, etc.). A better approach may be
    to add an upstream API for what you want to do ;)
  - Maildir's subFolder and maildirPath changed to maildir_path and sub_folder.
  * Features
  - add custom `change_command` to backlight widget
  - add CommandSet extension to list available commands
  - simplify battery monitoring widget interface and add freebsd
    compatible battery widget implementation
  - track last known mouse coordinates on the qtile manager
  - allow configuration of warping behavior in columns layout
  * Bugfixes
  - with cursor warp enabled, the cursor is warped on screen change
  - fix stepping groups to skip the scratch pad group
  - fix stack layout to properly shuffle
  - silence errors when unmapping windows
- Add python3-psutil as recommended dependency
- Increase python3-xcffib dependency version
- Remove _service file to stop tracking GitHub branch
- Change source to files.pythonhosted.org
* Tue May 14 2019 Petr Cervinka <petr@cervinka.net>
- Rename rpmlintrc to qtile-rpmlintrc
* Sun May 12 2019 petr@cervinka.net
- Update to version 0.13.0:
  * Deprecation
    wmii layout is deprecated in terms of columns layout, which has the
    same behavior with different defaults, see the wmii definition for
    more details
  * Features
  - add svg handling for images
  - allow addgroup command to set the layout
  - add command to get current log level
  - allow groupbox to hide unused groups
  - add caps lock indicator widget
  - add custom_command to check_update widget
  * Bugfixes
  - better shutdown handling
  - fix clientlist current client tracking
  - fix typo in up command on ratiotile layout
  - various fixes to check_update widget
  - fix 0 case for resize screen
- Add rpmlintrc to ignore warning related to dqtile-cmd
- Add python3-cairocffi-pixbuf dependency
- Increase python3-cairocffi dependency version
* Sat Jul 21 2018 petr@cervinka.net
- Update to version 0.12.0:
  * Fix floating bug in bsp layout
  * Fix name of `test_common`
  * Fix syntax error in mpd widget
  * Add error handling to mpd widget
  * Fix caps lock affected behaviour of key bindings
  * Use python2/3 switch for os.makedirs
  * Create cache dir if necessary
  * Fix typo in stack layout documentation
  * Fix mypy checks for mypy 0.600
  * Check for existence of BAT_DIR before listing it
* Wed May 16 2018 petr@cervinka.net
- Update to version 0.11.1+20180513.39ced15a:
  * Fix TaskList when not using markup
  * Fix the dmenu extension use of fontsize
  * Adds new formating options for tasklist
* Fri Apr  6 2018 petr@cervinka.net
- Update to version 0.11.1+20180406.68ddde55:
  * Fix up the docs build, improve some widget docs
  * Bugfix for wallpaper when user use custom wallpaper_command
  * Add mypy checks
  * Remove ignored flake8 errors
  * Volume runs command on right click
  * Fix for Tile layout where master windows are reversed on reset
  * Fix mistakes in example
* Thu Mar  8 2018 petr@cervinka.net
- Add python3-pyxdg, python3-python-mpd2, python3-python-dateutil,
  python3-keyring, python3-iwlib  and libxcb-cursor0 as recommended
  dependencies.
- Run spec-cleaner
* Tue Mar  6 2018 petr@cervinka.net
- Update to version 0.11.1+20180305.e741d3fe:
  * Added documentation for `no_reposition_match` option
  * Two fixes for floating windows:
  * Dropdown (like menu) Java windows are no longer positioned in the
    center of the screen (expected and correct behavior)
  * Added `no_reposition_match` option that allows to specify which
    floating windows should not be forcibly repositioned to the center
    of the screen
  * Rename qcmd and dqcmd to qtile-cmd and dqtile-cmd
  * Tile layout: unify commands so that it aligns well with other existing
    layouts
  * Guard previous and next when no current window
  * Make files transfer windows floating out of the box
  * Tile layout: fix master_match option by preserving _ClientList instead
    of replacing it with a plain list
  * Tile layout: add `add_after_last` option for new windows to be added at
    the end of the list
  * Unused variables removed
* Fri Mar  2 2018 petr@cervinka.net
- Update to version 0.11.1+20180301.ca27e5fa:
  * Bump setup.py version for sake of PyPI
  * Add bin/dqcmd to the MANIFEST file
- Migrate package to use service file
- Update versions for dependencies in spec file
* Thu Mar  1 2018 petr@cervinka.net
- Update to 0.11.0
  * Changed extension configuration, `extention` subpackage renamed to
    `extension`,  `extentions` configuration variable changed to
    `extension_defaults`. See documentation for full details.
  * Features
  - qshell improvements
  - new MonadWide layout
  - new Bsp layout
  - new pomodoro widget
  - new stock ticker widget
  - new `client_name_updated` hook
  - new RunCommand and J4DmenuDesktop extension
  - task list expands to fill space, configurable via `spacing` parameter
  - add group.focus_by_name() and group.info_by_name()
  - add disk usage ratio to df widget
  - allow displayed group name to differ from group name
  - enable custom TaskList icon size
  - add qcmd and dqcmd to extend functionality around qtile.command
    functionality
  - add ScratchPad group that has configurable drop downs
  * Bugfixes
  - fix race condition in Window.fullscreen
  - fix for string formatting in qtile_top
  - fix unicode literal in tasklist
  - move mpris2 initialization out of constructor
  - fix wlan widget variable naming and division
  - normalize behavior of layouts on various commands
  - add better fallback to default config
  - update btc widget to use coinbase
  - fix cursor warp when using default layout implementation
  - don't crash when using widget with unmet dependencies
  - fix floating window default location
* Thu Feb 22 2018 petr@cervinka.net
- Add jupyter console and ipykernel to suggests
* Mon Feb 12 2018 petr@cervinka.net
- Add qtile to update-alternatives
* Sun Feb  4 2018 jengelh@inai.de
- Ensure neutrality of descriptions.
* Fri Jan 26 2018 petr@cervinka.net
- Initial package version
